@@ -1,6 +1,6 @@
 /* funcproto.h: These definitions are not tunable.  Do not change them.
  *
- * $Id: funcproto.h 243 2003-12-05 12:38:37Z sam $
+ * $Id: funcproto.h 252 2004-08-09 20:05:25Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -28,18 +28,7 @@
  * THERE IS ABSOLUTELY NO WARRANTY FOR THIS SOFTWARE.
  */
 
-#if __STDC__ || defined(__cplusplus)
-#  undef WANT_PROTOTYPES
-#endif
-
-#ifdef WANT_PROTOTYPES
-#  define ELK_USE_PROTOTYPES
-#  define ELLIPSIS
-#endif
-
 #ifdef __cplusplus
-#  define ELK_USE_PROTOTYPES
-#  define ELLIPSIS ...
 #  define C_LINKAGE_BEGIN extern "C" {
 #  define C_LINKAGE_END   }
 #else
@@ -47,19 +36,3 @@
 #  define C_LINKAGE_END
 #endif
 
-#if __STDC__ && !defined(__cplusplus)
-#  define ELK_USE_PROTOTYPES
-#  define ELLIPSIS
-#endif
-
-#ifdef NO_PROTOTYPES
-#  undef ELK_USE_PROTOTYPES
-#endif
-
-#ifdef ELK_USE_PROTOTYPES
-#  define P_(args) args
-#else
-#  define P_(args) ()
-#  define ELLIPSIS
-#  define const
-#endif
