@@ -1,6 +1,6 @@
 /* gc.h
  *
- * $Id: gc.h 243 2003-12-05 12:38:37Z sam $
+ * $Id: gc.h 252 2004-08-09 20:05:25Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -118,7 +118,7 @@ extern GCNODE *GC_List;
 #define GC_Unlink (GC_List = gc1.next)
 
 C_LINKAGE_BEGIN
-extern void Func_Global_GC_Link P_((Object*));
+extern void Func_Global_GC_Link (Object*);
 C_LINKAGE_END
 
 #define Global_GC_Link(x) Func_Global_GC_Link(&x)
