@@ -1,7 +1,7 @@
 /* object.h: The Scheme object representation, and a few other important
  * data types.
  *
- * $Id: object.h 243 2003-12-05 12:38:37Z sam $
+ * $Id: object.h 258 2006-03-02 20:54:22Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -38,7 +38,7 @@ typedef struct {
 } Object;
 
 #define FIXBITS         (8 * (int)sizeof(int))
-#define SIGNBIT         ((unsigned)1 << (FIXBITS-1))
+#define SIGNBIT         ((unsigned int)1 << (FIXBITS-1))
 #define CONSTBIT        1
 #define TYPEBITS        (8 * (int)sizeof(int) - 1)
 #define MAX_TYPE        ((1 << TYPEBITS) - 1)
@@ -51,8 +51,8 @@ typedef struct {
 #define FIXNUM(x)       ((int)(x).data)
 #define CHAR(x)         ((int)(x).data)
 
-#define POINTER(x)      ((void *)(intptr_t)(x).data)
-#define SETPOINTER(x,p) ((x).data = (intptr_t)(void *)(p))
+#define POINTER(x)      ((void *)(uintptr_t)(x).data)
+#define SETPOINTER(x,p) ((x).data = (uintptr_t)(void *)(p))
 #define SET(x,t,p)      ((x).tag = (int)t << 1, (x).data = (p))
 
 #define ISCONST(x)      ((x).tag & CONSTBIT)
@@ -68,14 +68,14 @@ typedef struct {
 #ifdef GENERATIONAL_GC
 
    typedef int gcspace_t;                 /* type for space and type arrays */
-   typedef intptr_t gcptr_t;              /* type for pointers */
-   typedef long int pageno_t;             /* type for page numbers */
-   typedef intptr_t addrarith_t;          /* type for address arithmetic */
+   typedef uintptr_t gcptr_t;             /* type for pointers */
+   typedef uintptr_t pageno_t;            /* type for page numbers */
+   typedef uintptr_t addrarith_t;         /* type for address arithmetic */
 
    extern gcspace_t *space;
    extern gcspace_t current_space;
    C_LINKAGE_BEGIN
-   extern int Visit P_((Object*));    /* required for REVIVE_OBJ below */
+   extern int Visit (Object*);            /* required for REVIVE_OBJ below */
    C_LINKAGE_END
 
 #  ifdef ARRAY_BROKEN
@@ -95,7 +95,7 @@ typedef struct {
 #  define REVIVE_OBJ(obj)  Visit (&obj);
 #else
    C_LINKAGE_BEGIN
-   extern int Visit P_((Object*));    /* required in heap.c */
+   extern int Visit (Object*);        /* required in heap.c */
    C_LINKAGE_END
 #  define IS_ALIVE(obj)    WAS_FORWARDED(obj)
 #  define REVIVE_OBJ(obj)
@@ -185,7 +185,7 @@ struct S_Vector {
 enum discipline { EVAL, NOEVAL, VARARGS };
 struct S_Primitive {
     Object tag;
-    Object (*fun) P_((ELLIPSIS));
+    Object (*fun) ();
     const char *name;
     int minargs;
     int maxargs;    /* Or MANY */
@@ -209,7 +209,7 @@ typedef struct wind {
 typedef struct funct {
     struct funct *next;
     char *name;
-    void (*func) P_((void));
+    void (*func) (void);
 } FUNCT;
 
 typedef struct gcnode {
@@ -261,7 +261,7 @@ struct S_Port {
     unsigned int ptr;
     FILE *file;
     unsigned int lno;
-    int (*closefun) P_((FILE*));
+    int (*closefun) (FILE*);
 };
 #define P_OPEN    1 /* flags */
 #define P_INPUT   2
@@ -298,12 +298,12 @@ struct S_Macro {
 typedef struct {
     int haspointer;
     const char *name;
-    int (*size) P_((Object));
+    int (*size) (Object);
     int const_size;
-    int (*eqv) P_((Object, Object));
-    int (*equal) P_((Object, Object));
-    int (*print) P_((Object, Object, int, int, int));
-    int (*visit) P_((Object*, int (*)(Object*)));
+    int (*eqv) (Object, Object);
+    int (*equal) (Object, Object);
+    int (*print) (Object, Object, int, int, int);
+    int (*visit) (Object*, int (*)(Object*));
 } TYPEDESCR;
 
 #ifdef ELK_USE_PROTOTYPES
@@ -335,8 +335,8 @@ typedef struct {
 
 /* PFO, GENERIC, and MATCHFUN exist for backwards compatibility
  */
-typedef Object (*PFO) P_((Object));
-typedef int (*MATCHFUN) P_((ELLIPSIS));
+typedef Object (*PFO) (Object);
+typedef int (*MATCHFUN) ();
 #define GENERIC char*
 
 typedef struct weak_node {
@@ -359,4 +359,4 @@ typedef struct {
 
 /* Function that can be registered as a reader by Define_Reader():
  */
-typedef Object (*READFUN) P_((Object, int, int));
+typedef Object (*READFUN) (Object, int, int);
