@@ -1,6 +1,6 @@
 /* math.c: Generic math functions.
  *
- * $Id: math.c 243 2003-12-05 12:38:37Z sam $
+ * $Id: math.c 249 2004-01-29 13:55:42Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -746,6 +746,8 @@ Object Generic_Multiply (Object x, Object y) {
 
     switch (TYPE(x)) {
     case T_Fixnum:
+        if(FIXNUM(x) == 0)
+            return Zero;
         switch (TYPE(y)) {
         case T_Fixnum:
             ret = Fixnum_Multiply (FIXNUM(x), FIXNUM(y));
@@ -764,6 +766,8 @@ Object Generic_Multiply (Object x, Object y) {
     case T_Flonum:
         switch (TYPE(y)) {
         case T_Fixnum:
+            if(FIXNUM(y) == 0)
+                return Zero;
             return Make_Flonum (FLONUM(x)->val * FIXNUM(y));
         case T_Flonum:
             return Make_Flonum (FLONUM(x)->val * FLONUM(y)->val);
@@ -775,6 +779,8 @@ Object Generic_Multiply (Object x, Object y) {
     case T_Bignum:
         switch (TYPE(y)) {
         case T_Fixnum:
+            if(FIXNUM(y) == 0)
+                return Zero;
             return Bignum_Fixnum_Multiply (x, y);
         case T_Flonum:
             return Make_Flonum (Bignum_To_Double (x) * FLONUM(y)->val);
@@ -1100,6 +1106,8 @@ Object P_Sqrt (Object x) { return General_Function (x, Null, sqrt); }
 
 Object P_Exp (Object x) { return General_Function (x, Null, exp); }
 
+Object P_Pow (Object x, Object y) { return General_Function (x, y, pow); }
+
 Object P_Log (Object x) { return General_Function (x, Null, log); }
 
 Object P_Sin (Object x) { return General_Function (x, Null, sin); }
