@@ -1,7 +1,7 @@
 /* proc.c: Eval, funcall, apply, map, lambda, etc. The main-loop of the
  * Scheme evaluator.
  *
- * $Id: proc.c 243 2003-12-05 12:38:37Z sam $
+ * $Id: proc.c 261 2006-03-02 21:07:01Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -274,11 +274,17 @@ Object Funcall_Primitive (Object fun, Object argl, int eval) {
             prim = PRIM(fun);   /* fun has possibly been moved during gc */
         }
         if (prim->disc == VARARGS) {
-            r = (prim->fun)(argc, argv);
+            Object (*varfun) (int, Object *);
+            varfun = (Object (*) (int, Object *))prim->fun;
+            r = varfun(argc, argv);
         } else {
             switch (argc) {
-            case 0:
-                r = (prim->fun)(); break;
+            case 0: {
+                Object (*myfun) (void);
+                myfun = (Object (*) (void))prim->fun;
+                r = myfun();
+                break;
+            }
             case 1:
                 TC_Disable;
                 r = eval ? Eval (Car (argl)) : Car (argl);
