@@ -1,6 +1,6 @@
 /* type.c: Built-in and user-defined Scheme types.
  *
- * $Id: type.c 243 2003-12-05 12:38:37Z sam $
+ * $Id: type.c 260 2006-03-02 21:04:10Z sam $
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
  * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
@@ -112,6 +112,6 @@ void Init_Type() {
     memset(Types, 0, bytes);
     for (i = 0; (p = builtin_types[i]); i++) {
         Types[i].haspointer = *p != '0';
-        Types[i].name = ++p;
+        Types[i].name = p + 1; /* Skip first character */
     }
 }
